import tfsdk
options = tfsdk.ConfigurationOptions()
options.enable_GPU = True
options.fr_model = tfsdk.FACIALRECOGNITIONMODEL.FULL
sdk = tfsdk.SDK(options)
sdk.set_license('YOUR LICENSE KEY')

import cv2
import numpy as np
img_1 = cv2.imread('../sample_code/images/brad_pitt_1.jpg')
img_2 = cv2.imread('../sample_code/images/brad_pitt_2.jpg')

import cupy as cp

# load the image into the graphics card's memory
img_gpu_1 = cp.asarray(img_1)
# pass the gpu memory address to the sdk
sdk.set_image(img_gpu_1.data.ptr, img_1.shape[1], img_1.shape[0], tfsdk.COLORCODE.bgr, 0)
# detect the faces in the image without copying the image into the cpu memory
faces_1 = sdk.detect_faces()

# create an array to hold the face chip in the gpu memory
face_chip_1 = cp.zeros((112,112,3), 'uint8')
# the sdk copies the face chip into the allocated memory
sdk.extract_aligned_face(face_chip_1.data.ptr, faces_1[0])

img_gpu_2 = cp.asarray(img_2)
sdk.set_image(img_gpu_2.data.ptr, img_2.shape[1], img_2.shape[0], tfsdk.COLORCODE.bgr, 0)
faces_2 = sdk.detect_faces()

face_chip_2 = cp.zeros((112,112,3), 'uint8')
sdk.extract_aligned_face(face_chip_2.data.ptr, faces_2[0])


# check the face chip to see it looks fine
chip_img_1_cpu = face_chip_1.get()
cv2.imwrite('/tmp/face_1.jpg', cv2.cvtColor(chip_img_1_cpu, cv2.COLOR_BGR2RGB))

chip_img_2_cpu = face_chip_2.get()
cv2.imwrite('/tmp/face_2.jpg', cv2.cvtColor(chip_img_2_cpu, cv2.COLOR_BGR2RGB))

# extract faceprints
face_chips = [face_chip_1.data.ptr, face_chip_2.data.ptr]
status, faceprints = sdk.get_face_feature_vectors(face_chips)

# compare the two faceprints, this should return a high match probability
res = faceprints[0].compare(faceprints[1])
print(res)

